@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package YAML::PP::Schema::Perl;
 
-our $VERSION = '0.034_001'; # TRIAL VERSION
+our $VERSION = '0.035_001'; # TRIAL VERSION
 
 use Scalar::Util qw/ blessed reftype /;
 
@@ -19,13 +19,15 @@ my $qr_prefix;
 sub new {
     my ($class, %args) = @_;
     my $tags = $args{tags} || [];
-    my $loadcode = $args{loadcode};
-    $loadcode ||= 0;
+    my $loadcode = $args{loadcode} || 0;
+    my $dumpcode = $args{dumpcode};
+    $dumpcode = 1 unless defined $dumpcode;
     my $classes = $args{classes};
 
     my $self = bless {
         tags => $tags,
         loadcode => $loadcode,
+        dumpcode => $dumpcode,
         classes => $classes,
     }, $class;
 }
@@ -36,11 +38,13 @@ sub register {
 
     my $tags;
     my $loadcode = 0;
+    my $dumpcode = 1;
     my $classes;
     if (blessed($self)) {
         $tags = $self->{tags};
         @$tags = ('!perl') unless @$tags;
         $loadcode = $self->{loadcode};
+        $dumpcode = $self->{dumpcode};
         $classes = $self->{classes};
     }
     else {
@@ -53,6 +57,9 @@ sub register {
             elsif ($option eq '+loadcode') {
                 $loadcode = 1;
             }
+            elsif ($option eq '-dumpcode') {
+                $dumpcode = 0;
+            }
         }
         $tags = [split m/\+/, $tagtype];
     }
@@ -353,14 +360,26 @@ sub register {
             $node->{data} = $self->represent_ref($node->{value});
         },
     );
-    $schema->add_representer(
-        coderef => 1,
-        code => sub {
-            my ($rep, $node) = @_;
-            $node->{tag} = $perl_tag . "/code";
-            $node->{data} = $self->represent_code($node->{value});
-        },
-    );
+    if ($dumpcode) {
+        $schema->add_representer(
+            coderef => 1,
+            code => sub {
+                my ($rep, $node) = @_;
+                $node->{tag} = $perl_tag . "/code";
+                $node->{data} = $self->represent_code($node->{value});
+            },
+        );
+    }
+    else {
+        $schema->add_representer(
+            coderef => 1,
+            code => sub {
+                my ($rep, $node) = @_;
+                $node->{tag} = $perl_tag . "/code";
+                $node->{data} = '{ "DUMMY" }';
+            },
+        );
+    }
     $schema->add_representer(
         glob => 1,
         code => sub {
@@ -878,6 +897,7 @@ YAML:
         tags => "!perl",
         classes => ['MyClass'],
         loadcode => 1,
+        dumpcode => 1,
     );
 
 The constructor recognizes the following options:
@@ -902,6 +922,12 @@ Accepts an array ref of class names
 
 Default: 0
 
+=item dumpcode
+
+Default: 1
+
+    my $yp = YAML::PP->new( schema => [qw/ + Perl -dumpcode /] );
+
 =back
 
 =item register
